@@ -111,56 +111,55 @@ sub _set_menu_select_editor {
 	# If there is already a 'value' property set in editor save it to preserve it (see below):
 	my $orig_value = ref($self->{editor}) eq 'HASH' ? $self->{editor}->{value} : undef;
 	
-	unless (defined $self->{allow_edit} and !jstrue($self->{allow_edit})) {
-	
-		my $mode = $new->{mode} || 'combo';
-		
-		if($mode eq 'combo') {
-			$self->{editor} = {
-				xtype => 'ra-icon-combo',
-				allowBlank => \0,
-				value_list => \@value_list,
-			};
-		}
-		elsif($mode eq 'menu') {
-		
-			$self->{editor} = {
-				xtype => 'menu-field',
-				menuOnShow => \1,
-				value_list => \@value_list,
-				value => $first_val,
-				minHeight => 10,
-				minWidth => 10
-			};
-			
-			$self->{editor}->{header} = $new->{header} || $self->header;
-			delete $self->{editor}->{header} unless (
-				defined $self->{editor}->{header} and
-				$self->{editor}->{header} ne ''
-			);
-		
-		}
-		elsif($mode eq 'cycle') {
-		
-			$self->{editor} = {
-				xtype => 'cycle-field',
-				cycleOnShow => \1,
-				value_list => \@value_list,
-				value => $first_val,
-				minHeight => 10,
-				minWidth => 10
-			};
-		
-		}
-		else {
-			die "menu_select_editor: Invalid mode '$mode' - must be 'combo', 'menu' or 'cycle'"
-		}
-		
-		# restore the original 'value' if it was already defined (see above)
-		$self->{editor}->{value} = $orig_value if (defined $orig_value);
-		
-		$self->{editor}->{width} = $new->{width} if ($new->{width});
-	}
+  # Update: removed extra, not-needed check of 'allow_edit' param (fixes Github Issue #35)
+
+  my $mode = $new->{mode} || 'combo';
+  
+  if($mode eq 'combo') {
+    $self->{editor} = {
+      xtype => 'ra-icon-combo',
+      allowBlank => \0,
+      value_list => \@value_list,
+    };
+  }
+  elsif($mode eq 'menu') {
+  
+    $self->{editor} = {
+      xtype => 'menu-field',
+      menuOnShow => \1,
+      value_list => \@value_list,
+      value => $first_val,
+      minHeight => 10,
+      minWidth => 10
+    };
+    
+    $self->{editor}->{header} = $new->{header} || $self->header;
+    delete $self->{editor}->{header} unless (
+      defined $self->{editor}->{header} and
+      $self->{editor}->{header} ne ''
+    );
+  
+  }
+  elsif($mode eq 'cycle') {
+  
+    $self->{editor} = {
+      xtype => 'cycle-field',
+      cycleOnShow => \1,
+      value_list => \@value_list,
+      value => $first_val,
+      minHeight => 10,
+      minWidth => 10
+    };
+  
+  }
+  else {
+    die "menu_select_editor: Invalid mode '$mode' - must be 'combo', 'menu' or 'cycle'"
+  }
+  
+  # restore the original 'value' if it was already defined (see above)
+  $self->{editor}->{value} = $orig_value if (defined $orig_value);
+  
+  $self->{editor}->{width} = $new->{width} if ($new->{width});
 }
 
 sub _set_allow_edit {
